@@ -19,7 +19,7 @@ class TextEmbeddingItem(Record):
 
 
 class TextSchema(Record):
-    items = Array(TextItem)
+    items = Array(TextItem())
 
 
 class TextEmbeddingSchema(Record):
